import 'package:flutter/material.dart';
import 'package:hx_components_flutter/hx_components.dart';
import 'package:hx_components_flutter/hx_utils.dart';

// ignore: must_be_immutable
class HxListItem extends StatelessWidget {
  final String title;
  final String description;
  final IconData icon;
  final VoidCallback onTap;
  Color? bgColor;
  Color textColor;
  Color? arrowIconColor;
  Color borderColor;
  Color? clickColor;
  bool enabled;
  bool loading;

  HxListItem.white({
    required this.title,
    required this.onTap,
    this.icon = Icons.arrow_forward_ios,
    this.description = '',
    this.enabled = true,
    this.loading = false,
  })  : bgColor = kcBackgroundColor,
        textColor = kcMainText,
        arrowIconColor = kcDarkGrey,
        borderColor = kcLightGrey,
        clickColor = kcPrimaryColor;

  HxListItem.blue({
    required this.title,
    required this.onTap,
    this.icon = Icons.arrow_forward_ios,
    this.description = '',
    this.enabled = true,
    this.loading = false,
  })  : bgColor = kcPrimaryColor,
        textColor = kcBackgroundColor,
        arrowIconColor = kcBackgroundColor,
        borderColor = kcPrimaryColor,
        clickColor = null;

  @override
  Widget build(BuildContext context) {
    return Material(
      elevation: enabled ? 0 : 1,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(10),
        side: BorderSide(color: borderColor, width: 2.0),
      ),
      color: enabled ? bgColor : kcLightGrey,
      //height: MediaQuery.of(context).size.height * 0.18,
      child: InkWell(
        onTap: enabled ? onTap : null,
        splashColor: clickColor,
        //hoverColor: bgColor,
        borderRadius: BorderRadius.circular(10),
        child: Ink(
          padding: const EdgeInsets.all(15.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Row(
                children: [
                  Container(
                    padding: const EdgeInsets.all(8.0),
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(12.0),
                      color: kcLightGrey,
                    ),
                    child: Icon(
                      icon,
                      color: enabled ? kcSecondaryColor : kcDarkGrey,
                      size: MediaQuery.of(context).size.width * 0.08,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.only(left: 10.0),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        HxText.heading3(
                          title,
                          fontWeight: FontWeight.normal,
                          color: enabled ? textColor : kcDarkGrey,
                        ),
                        if (description.isEmpty)
                          Container()
                        else
                          HxText.custom(
                            description,
                            style: TextStyle(
                              color: enabled
                                  ? bgColor == kcBackgroundColor
                                      ? kcDarkGrey
                                      : kcBackgroundColor
                                  : kcDarkGrey,
                              fontSize: 12.0,
                            ),
                          )
                      ],
                    ),
                  ),
                ],
              ),
              if (loading)
                SizedBox(
                  height: 15,
                  width: 15,
                  child: CircularProgressIndicator(strokeWidth: 2.5, color: enabled ? kcPrimaryColor : kcDarkGrey),
                )
              else
                Icon(
                  Icons.arrow_forward_ios,
                  size: 15.0,
                  color: arrowIconColor,
                )
            ],
          ),
        ),
      ),
    );
  }
}
