import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/hx_components.dart';
import 'package:hx_components_flutter/src/shared/app_colors.dart';

class HxMultiDropdownSearch<T> extends StatelessWidget {
  final String label;
  final String? hint;
  final List<T> items;
  final List<T>? initialSelectedItems;
  final bool? isLoading;
  final Function(List<T>?) onChanged;
  final Future<List<T>> Function(String)? asyncItems;
  final Widget Function(BuildContext, T, bool)? itemBuilder;
  final bool enabled;
  final Widget Function(BuildContext, List<T>?)? dropdownBuilder;
  final Widget Function(BuildContext, String)? emptyBuilder;

  const HxMultiDropdownSearch({
    super.key,
    required this.items,
    required this.onChanged,
    required this.label,
    this.isLoading,
    this.hint,
    this.initialSelectedItems,
    this.itemBuilder,
    this.enabled = true,
    this.dropdownBuilder,
    this.emptyBuilder,
  }) : asyncItems = null;

  HxMultiDropdownSearch.async({
    super.key,
    required this.onChanged,
    required this.label,
    required this.asyncItems,
    this.isLoading,
    this.hint,
    this.initialSelectedItems,
    this.itemBuilder,
    this.enabled = true,
    this.dropdownBuilder,
    this.emptyBuilder,
  }) : items = [];

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        DropdownSearch<T>.multiSelection(
          enabled: enabled,
          asyncItems: asyncItems,
          selectedItems: initialSelectedItems ?? [],
          dropdownBuilder: dropdownBuilder,
          popupProps: PopupPropsMultiSelection.menu(
            selectionWidget: (context, item, isSelected) => Padding(
              padding: const EdgeInsets.symmetric(horizontal: 8),
              child: HxCheckbox.light(
                value: isSelected,
                onTap: () {
                  isSelected = !isSelected;
                },
              ),
            ),
            emptyBuilder: emptyBuilder,
            itemBuilder: itemBuilder,
            fit: FlexFit.loose,
            showSearchBox: true,
            searchFieldProps: TextFieldProps(
              style: const TextStyle(fontSize: 16),
              decoration: InputDecoration(
                suffixIcon: const Icon(Icons.search),
                labelStyle: TextStyle(color: kcPrimaryColor),
                border: OutlineInputBorder(
                  borderSide: BorderSide(color: kcPrimaryColor),
                ),
              ),
            ),
          ),
          items: items,
          dropdownDecoratorProps: DropDownDecoratorProps(
            baseStyle: const TextStyle(fontSize: 16),
            dropdownSearchDecoration: InputDecoration(
              labelText: label,
              hintText: hint,
              filled: true,
              fillColor: kcLightGrey,
              isDense: true,
              disabledBorder: const UnderlineInputBorder(
                borderSide: BorderSide(color: kcDarkGrey),
              ),
            ),
          ),
          onChanged: onChanged,
        ),
        if (isLoading ?? false) const LinearProgressIndicator() else const SizedBox(),
      ],
    );
  }
}
